Index: tools/bc-tohtml.rb
===================================================================
--- tools/bc-tohtml.rb	(revision 2253)
+++ tools/bc-tohtml.rb	(working copy)
@@ -30,6 +30,9 @@
   parser.on('--target=NAME', 'Compile NAME to HTML.') {|name|
     target = name
   }
+  parser.on('--force', '-f', 'force to use rd_file template.') {|name|
+    @rd_file = true
+  }
   parser.on('--baseurl=URL', 'Base URL of generated HTML') {|url|
     baseurl = url
   }
@@ -57,13 +60,25 @@
                                         :base_url => baseurl,
                                         :cgi_url => baseurl,
                                         :default_encoding => 'euc-jp')
-  begin
-    lib = BitClust::RRDParser.parse_stdlib_file(ARGV[0])
-    entry = target ? lookup(lib, target) : lib
-    puts manager.entry_screen(entry).body
-  rescue BitClust::ParseError
-    puts manager.rd_file_screen(ARGF.read).body
+  unless @rd_file
+    begin
+      lib = BitClust::RRDParser.parse_stdlib_file(ARGV[0])
+      entry = target ? lookup(lib, target) : lib
+      puts manager.entry_screen(entry).body
+      exit 0
+    rescue BitClust::ParseError => ex
+      $stderr.puts ex.message
+      $stderr.puts ex.backtrace.map{|s| "\tfrom " + s}
+    end
   end
+  
+  ret = ''
+  io = BitClust::Preprocessor.new(File.open(ARGV[0]))
+  while s = io.gets
+    ret << s
+  end
+  puts manager.rd_file_screen(ret).body
+  
 rescue BitClust::WriterError => err
   $stderr.puts err.message
   exit 1
Index: lib/bitclust/screen.rb
===================================================================
--- lib/bitclust/screen.rb	(revision 2253)
+++ lib/bitclust/screen.rb	(working copy)
@@ -335,9 +335,9 @@
   end
 
   class RDFileScreen < TemplateScreen
-    def initialize(u, t, e, entry)
+    def initialize(u, t, e, s)
       super u, t, e
-      @entry = entry
+      @source = s
     end
 
     def encoding
@@ -348,5 +348,9 @@
     def body
       run_template('rd_file')
     end
+    
+    def rdcompiler
+      RDCompiler.new(@urlmapper, @hlevel, {:force => true})
+    end
   end
 end
Index: lib/bitclust/rdcompiler.rb
===================================================================
--- lib/bitclust/rdcompiler.rb	(revision 2252)
+++ lib/bitclust/rdcompiler.rb	(working copy)
@@ -19,13 +19,14 @@
     include HTMLUtils
     include TextUtils
 
-    def initialize(urlmapper, hlevel = 1)
+    def initialize(urlmapper, hlevel = 1, opt = {})
       @urlmapper = urlmapper
       @hlevel = hlevel
       @type = nil
       @library = nil
       @class = nil
       @method = nil
+      @option = opt.dup
     end
 
     def compile(src)
@@ -99,7 +100,11 @@
         when /\A===+/
           headline @f.gets
         when /\A==?/
-          raise "method entry includes headline: #{@f.peek.inspect}"
+          if @option[:force]
+            break
+          else
+            raise "method entry includes headline: #{@f.peek.inspect}"
+          end
         when /\A---/
           break
         when /\A\s+\*\s/
@@ -123,6 +128,7 @@
         end
       end
       @out.puts '</dd>'
+      @out.puts '</dl>' if @option[:force]
     end
 
     def headline(line)
@@ -278,6 +284,7 @@
 
     def method_signature(sig)
       # FIXME: check parameters, types, etc.
+      string '<dl>' if @option[:force]
       string '<dt><code>'
       string escape_html(sig.sub(/\A---/, '').strip)
       string '</code>'
Index: template.offline/rd_file
===================================================================
--- template.offline/rd_file	(revision 2253)
+++ template.offline/rd_file	(working copy)
@@ -11,5 +11,5 @@
 headline_push
 headline_push
 %>
-<%= compile_rd(@entry) %>
+<%= compile_rd(@source) %>
 </body>
\ No newline at end of file
